@@ -1,6 +1,6 @@
 ;;; orderless-kwd.el --- Keyword dispatcher -*- lexical-binding: t -*-
 
-;; Copyright (C) 2024 Free Software Foundation, Inc.
+;; Copyright (C) 2024-2025 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2024
@@ -57,6 +57,7 @@
     (cat ,#'orderless-kwd-category)
     (con ,#'orderless-kwd-content)
     (dir ,#'orderless-kwd-directory)
+    (fil ,#'orderless-kwd-file)
     (doc ,#'orderless-kwd-documentation)
     (grp ,#'orderless-kwd-group)
     (mod ,#'orderless-kwd-mode)
@@ -201,6 +202,13 @@ as a flag and does not require input."
       (orderless--match-p pred regexp
                           (buffer-local-value 'default-directory buf)))))
 
+(defun orderless-kwd-file (pred regexp)
+  "Match `buffer-file-truename' against PRED and REGEXP."
+  (lambda (str)
+    (when-let ((buf (orderless-kwd--get-buffer str)))
+      (orderless--match-p pred regexp
+                          (buffer-local-value 'buffer-file-truename buf)))))
+
 ;;;###autoload
 (defun orderless-kwd-dispatch (component _index _total)
   "Match COMPONENT against the keywords in `orderless-kwd-alist'."
