@@ -1,12 +1,12 @@
 ;;; orderless.el --- Completion style for matching regexps in any order  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
 
 ;; Author: Omar Antolín Camarena <omar@matem.unam.mx>
 ;; Maintainer: Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler <mail@daniel-mendler.de>
-;; Keywords: extensions
-;; Version: 1.2
-;; Homepage: https://github.com/oantolin/orderless
+;; Keywords: matching, completion
+;; Version: 1.4
+;; URL: https://github.com/oantolin/orderless
 ;; Package-Requires: ((emacs "27.1") (compat "30"))
 
 ;; This file is part of GNU Emacs.
@@ -60,6 +60,9 @@
 
 (defgroup orderless nil
   "Completion method that matches space-separated regexps in any order."
+  :link '(info-link :tag "Info Manual" "(orderless)")
+  :link '(url-link :tag "Website" "https://github.com/oantolin/orderless")
+  :link '(emacs-library-link :tag "Library Source" "orderless.el")
   :group 'minibuffer)
 
 (defface orderless-match-face-0
@@ -495,7 +498,7 @@ The predicate PRED is used to constrain the entries in TABLE."
                (prefix (substring string 0 limit))
                (pattern (substring string limit))
                (`(,fun . ,regexps) (orderless-compile pattern)))
-    (list prefix regexps (orderless--ignore-case-p regexps)
+    (list prefix regexps (orderless--ignore-case-p pattern)
           (orderless--predicate-normalized-and pred fun))))
 
 ;; Thanks to @jakanakaevangeli for writing a version of this function:
@@ -516,7 +519,7 @@ then return (cons REGEXP u); else return nil."
 (defun orderless--ignore-case-p (regexps)
   "Return non-nil if case should be ignored for REGEXPS."
   (if orderless-smart-case
-      (cl-loop for regexp in regexps
+      (cl-loop for regexp in (ensure-list regexps)
                always (isearch-no-upper-case-p regexp t))
     completion-ignore-case))
 
